@@ -3,11 +3,11 @@
 
 import time
 import board
-import busio
 import adafruit_adt7410
 
-i2c_bus = busio.I2C(board.SCL, board.SDA)
-adt = adafruit_adt7410.ADT7410(i2c_bus, address=0x48)
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
+adt = adafruit_adt7410.ADT7410(i2c, address=0x48)
 adt.high_resolution = True
 
 while True:
